@@ -1,5 +1,8 @@
 var searchbarPlugins = require('searchbar/searchbarPlugins.js')
 var searchbarUtils = require('searchbar/searchbarUtils.js')
+var urlParser = require('util/urlParser.js')
+
+var places = require('places/places.js')
 
 function showPlaceSuggestions (text, input, event, container) {
   // use the current tab's url for history suggestions, or the previous tab if the current tab is empty
@@ -12,7 +15,7 @@ function showPlaceSuggestions (text, input, event, container) {
     }
   }
 
-  bookmarks.getPlaceSuggestions(url, function (results) {
+  places.getPlaceSuggestions(url, function (results) {
     empty(container)
 
     var tabList = tabs.get().map(function (tab) {
@@ -29,7 +32,7 @@ function showPlaceSuggestions (text, input, event, container) {
         secondaryText: searchbarUtils.getRealTitle(result.title),
         url: result.url,
         delete: function () {
-          bookmarks.deleteHistory(result.url)
+          places.deleteHistory(result.url)
         }
       })
 
@@ -45,37 +48,3 @@ searchbarPlugins.register('placeSuggestions', {
   },
   showResults: showPlaceSuggestions
 })
-
-// when we get keywords data from the page, we show those results in the searchbar
-
-webviews.bindIPC('keywordsData', function (webview, tabId, args) {
-  var data = args[0]
-
-  var itemsCt = 0
-  var itemsShown = []
-
-  var container = searchbarPlugins.getContainer('searchSuggestions')
-
-  data.entities.forEach(function (item, index) {
-    // ignore one-word items, they're usually useless
-    if (!/\s/g.test(item.trim())) {
-      return
-    }
-
-    if (itemsCt >= 5 || itemsShown.indexOf(item.trim()) !== -1) {
-      return
-    }
-
-    var div = searchbarUtils.createItem({
-      icon: 'fa-search',
-      title: item,
-      url: item,
-      classList: ['iadata-onfocus']
-    })
-
-    container.appendChild(div)
-
-    itemsCt++
-    itemsShown.push(item.trim())
-  })
-})
